@@ -6,7 +6,7 @@ import time
 from concurrent import futures
 from datetime import datetime
 from functools import cached_property
-from typing import Optional, Union
+from typing import Optional
 
 from packaging import version
 
@@ -155,12 +155,12 @@ class ADependencyGithubRelease(
         return await self.timestamp_commit
 
     @cached_property
-    def version(
-            self) -> Union[
-                version.LegacyVersion,
-                version.Version]:
+    def version(self) -> Optional[version.Version]:
         """Semantic version of this release."""
-        return version.parse(self.tag_name)
+        try:
+            return version.parse(self.tag_name)
+        except version.InvalidVersion:
+            return None
 
     def should_hash_in_proc(self, data: bytes) -> bool:
         """Conditionally generate SHA hashes based on incoming data."""
